@@ -41,6 +41,8 @@ CODE_BUILD_RUNS = "code-build-runs"
 CODE_BUILD_RUN = "code-build-run"
 SERVICE_CONTROL_POLICIES = "service-control-policies"
 SERVICE_CONTROL_POLICY = "service-control-policy"
+TAG_POLICIES = "tag-policies"
+TAG_POLICY = "tag-policy"
 
 SIMULATE_POLICIES = "simulate-policies"
 SIMULATE_POLICY = "simulate-policy"
@@ -137,6 +139,7 @@ ALL_SECTION_NAMES = [
     WORKSPACES,
     SERVICE_CONTROL_POLICIES,
     SIMULATE_POLICIES,
+    TAG_POLICIES,
 ]
 
 ALL_SPOKE_EXECUTABLE_SECTION_NAMES = [
@@ -239,6 +242,7 @@ SECTIONS_THAT_SUPPORT_CONDITIONS = [
     LAMBDA_INVOCATIONS,
     CODE_BUILD_RUNS,
     SERVICE_CONTROL_POLICIES,
+    TAG_POLICIES,
     SIMULATE_POLICIES,
     ASSERTIONS,
 ]
